==> resin-3.1.13-src.tar.gz: resin-3.1.13/modules/resin/src/com/caucho/server/rewrite/RewriteRule.java <==
/*
 * Copyright (c) 1998-2008 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.server.rewrite;

import com.caucho.config.ConfigException;

import javax.servlet.FilterChain;
import javax.servlet.ServletException;
import java.util.regex.Matcher;

public class RewriteRule
  extends AbstractRuleWithConditions
{
  private String _replacement;

  protected RewriteRule(RewriteDispatch rewriteDispatch)
  {
    super(rewriteDispatch);
  }

  public String getTagName()
  {
    return "rewrite";
  }

  /**
   * Sets the target.
   */
  public void setReplacement(String replacement)
  {
    _replacement = replacement;
  }

  /**
   * Init
   */
  @Override
  public void init()
    throws ConfigException
  {
    super.init();

    required(_replacement, "replacement");
  }

  @Override
  public String rewrite(String uri, Matcher matcher)
  {
    return matcher == null ? _replacement : matcher.replaceAll(_replacement);
  }

  public FilterChain dispatch(String uri,
			      String queryString,
                              FilterChain accept,
                              FilterChainMapper next)
    throws ServletException
  {
    return null;
  }
}

==> resin-4.0.65-src.tar.gz: resin-4.0.65/modules/resin/src/com/caucho/server/rewrite/RewriteRule.java <==
/*
 * Copyright (c) 1998-2018 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.server.rewrite;

import com.caucho.config.ConfigException;

import javax.annotation.PostConstruct;
import javax.servlet.FilterChain;
import javax.servlet.ServletException;
import java.util.regex.Matcher;

public class RewriteRule
  extends AbstractRuleWithConditions
{
  private String _target;

  protected RewriteRule(RewriteDispatch rewriteDispatch)
  {
    super(rewriteDispatch);
  }

  public String getTagName()
  {
    return "rewrite";
  }

  /**
   * Sets the target.
   */
  public void setReplacement(String replacement)
  {
    setTarget(replacement);
  }

  /**
   * Sets the target.
   */
  public void setTarget(String target)
  {
    _target = target;
  }

  /**
   * Init
   */
  @Override
  @PostConstruct
  public void init()
    throws ConfigException
  {
    super.init();

    required(_target, "target");
  }

  @Override
  public String rewrite(String uri, Matcher matcher)
  {
    return matcher == null ? _target : matcher.replaceAll(_target);
  }

  public FilterChain dispatch(String uri,
                              String queryString,
                              FilterChain accept,
                              FilterChainMapper next)
    throws ServletException
  {
    return null;
  }
}
